@@ -104,15 +104,6 @@
                                           Ci.nsIPrefLocalizedString).data
     });
 
-  const newTab = url => {
-    const browser = WindowMediator.getMostRecentBrowserWindow().gBrowser;
-
-    browser.selectedTab = browser.addTab(url, {
-      triggeringPrincipal: ScriptSecurity.getSystemPrincipal(),
-      fromExternal: true
-    });
-  };
-
   const onKey = e => {
     const k = e.key.toLowerCase();
     let f;
@@ -188,8 +179,18 @@
         input.close();
       }
 
-      if (line.slice(-1) === RecordSep)
-        newTab(line.slice(0, -1));
+      if (line.slice(-1) !== RecordSep)
+        return;
+
+      const urls    = line.slice(0, -1).split(FieldSep);
+      const browser = WindowMediator.getMostRecentBrowserWindow().gBrowser;
+      const params  = {
+        skipAnimation: urls.length > 1,
+        triggeringPrincipal: ScriptSecurity.getSystemPrincipal(),
+        fromExternal: true
+      };
+
+      browser.selectedTab = urls.map(url => browser.addTab(url, params))[0];
     }
   });
 })();
